==> deepin-manual_6.5.6.1.tar.xz: BUILD/translations/deepin-manual_ug.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ug">
<context>
    <name>ManualProxy</name>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="311"/>
        <source>Desktop Environment</source>
        <translation>ئۈستەليۈزى مۇھىتى</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/app/dman.cpp" line="107"/>
        <source>Manual</source>
        <translation>قوللانما</translation>
    </message>
    <message>
        <location filename="../src/app/dman.cpp" line="108"/>
        <source>Manual is designed to help users learn the operating system and its applications, providing specific instructions and function descriptions.</source>
        <translation>قوللانما ئىشلەتكۈچىلەرنىڭ مەشغۇلات سىستېمىسى ۋە ئۇنىڭ قوللىنىشچان پىروگراممىلىرىنى چۈشىنىشىگە ياردەم بېرىش ھەمدە كونكرېت چۈشەندۈرۈش ۋە ئىقتىدار چۈشەندۈرۈشى بىلەن تەمىنلەشنى مەقسەت قىلغان</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="21"/>
        <source>System</source>
        <translation>سېستىما </translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="22"/>
        <source>Applications</source>
        <translation>پروگراممىلار </translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="25"/>
        <source>No search results</source>
        <translation>ئىزدەش نەتىجىسى يوق</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="28"/>
        <source>Home</source>
        <translation>باش بەت </translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="30"/>
        <source>  result</source>
        <translation>نەتىجە</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="31"/>
        <source>  results</source>
        <translation>نەتىجە</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="591"/>
        <source>Search</source>
        <translation>ئىزدەش </translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="594"/>
        <source>Support</source>
        <translation>قوللاش</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="275"/>
        <source>The content was updated</source>
        <translation>نۆۋەتتتىكى مەزمۇن يېڭىلانغان</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="795"/>
        <source>Copy</source>
        <translation>نۇسخىلاش</translation>
    </message>
    <message>
        <location filename="../src/view/widget/search_completion_window.cpp" line="163"/>
        <location filename="../src/view/widget/search_completion_window.cpp" line="249"/>
        <source>Search for &quot;%1&quot; in the full text</source>
        <translation>“%1”پۈتۈن مەزمۇن ئىچىدىن ئىزدەۋاتىدۇ </translation>
    </message>
</context>
<context>
    <name>WebWindow</name>
    <message>
        <location filename="../src/view/web_window.cpp" line="729"/>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="744"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
</context>
</TS>

==> deepin-manual_6.5.25.tar.xz: BUILD/translations/deepin-manual_ug.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" sourcelanguage="en_US" language="ug">
<context>
    <name>ManualProxy</name>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="322"/>
        <source>Learn Basic Operations</source>
        <translation>ئاساسىي مەشغۇلاتنى چۈشىنىش</translation>
    </message>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="324"/>
        <source>Common Application Libraries</source>
        <translation>دائىملىق ئەپلەر</translation>
    </message>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="326"/>
        <source>Desktop Environment</source>
        <translation>ئۈستەليۈزى مۇھىتى</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/view/widget/search_completion_window.cpp" line="163"/>
        <location filename="../src/view/widget/search_completion_window.cpp" line="249"/>
        <source>Search for &quot;%1&quot; in the full text</source>
        <translation>“%1”پۈتۈن مەزمۇن ئىچىدىن ئىزدەۋاتىدۇ </translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="301"/>
        <source>The content was updated</source>
        <translation>نۆۋەتتتىكى مەزمۇن يېڭىلانغان</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="624"/>
        <source>Search</source>
        <translation>ئىزدەش </translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="627"/>
        <location filename="../src/view/i18n_proxy.cpp" line="31"/>
        <source>Support</source>
        <translation>قوللاش</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="836"/>
        <source>Copy</source>
        <translation>نۇسخىلاش</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="21"/>
        <source>Quick Start</source>
        <translation>تېزدىن تونۇشۇش</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="22"/>
        <source>Video Guide</source>
        <translation>سىن كۆرسەتمىسى</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="23"/>
        <source>System</source>
        <translation>سېستىما </translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="24"/>
        <source>Applications</source>
        <translation>پروگراممىلار </translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="25"/>
        <source>No search results</source>
        <translation>ئىزدەش نەتىجىسى يوق</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="26"/>
        <source>Home</source>
        <translation>باش بەت </translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="27"/>
        <source>  result</source>
        <translation>نەتىجە</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="28"/>
        <source>  results</source>
        <translation>نەتىجە</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="29"/>
        <source>Click to view </source>
        <translation>چېكىپ كۆرۈش</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="30"/>
        <source>View all</source>
        <translation>ھەممىنى كۆرۈش</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="32"/>
        <source>App Store</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/app/dman.cpp" line="105"/>
        <source>Manual</source>
        <translation>قوللانما</translation>
    </message>
    <message>
        <location filename="../src/app/dman.cpp" line="106"/>
        <source>Manual is designed to help users learn the operating system and its applications, providing specific instructions and function descriptions.</source>
        <translation>قوللانما ئىشلەتكۈچىلەرنىڭ مەشغۇلات سىستېمىسى ۋە ئۇنىڭ قوللىنىشچان پىروگراممىلىرىنى چۈشىنىشىگە ياردەم بېرىش ھەمدە كونكرېت چۈشەندۈرۈش ۋە ئىقتىدار چۈشەندۈرۈشى بىلەن تەمىنلەشنى مەقسەت قىلغان</translation>
    </message>
</context>
<context>
    <name>WebWindow</name>
    <message>
        <location filename="../src/view/web_window.cpp" line="765"/>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="780"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
</context>
</TS>
